Internal Classes
================
.. automodule:: holmium.core.pageobject 

.. autoclass:: PageElementDict
.. autoclass:: PageElementList
.. autoclass:: ElementGetter
.. autofunction:: enhanced

.. automodule:: holmium.core 

.. autoclass:: HolmiumNose

